Module: xenomai-head
Branch: master
Commit: dbc99707421cfb4a0ce0c78af9565d9a0e6a4a63
URL:    
http://git.xenomai.org/?p=xenomai-head.git;a=commit;h=dbc99707421cfb4a0ce0c78af9565d9a0e6a4a63

Author: Alexis Berlemont <alexis.berlem...@gmail.com>
Date:   Wed Oct 28 00:45:27 2009 +0100

analogy: add modules descriptions and license specifications

---

 ksrc/drivers/analogy/intel/8255.c                  |   10 ++++++----
 .../analogy/national_instruments/mio_common.c      |    3 +++
 ksrc/drivers/analogy/national_instruments/pcimio.c |    2 ++
 .../analogy/national_instruments/tio_common.c      |    2 +-
 4 files changed, 12 insertions(+), 5 deletions(-)

diff --git a/ksrc/drivers/analogy/national_instruments/mio_common.c 
b/ksrc/drivers/analogy/national_instruments/mio_common.c
index 19f3431..d23ee12 100644
--- a/ksrc/drivers/analogy/national_instruments/mio_common.c
+++ b/ksrc/drivers/analogy/national_instruments/mio_common.c
@@ -5196,6 +5196,9 @@ int ni_E_init(a4l_dev_t *dev)
        return 0;
 }
 
+MODULE_DESCRIPTION("Analogy support for NI DAQ-STC based boards");
+MODULE_LICENSE("GPL");
+
 EXPORT_SYMBOL(range_ni_E_ai);
 EXPORT_SYMBOL(range_ni_E_ai_limited);
 EXPORT_SYMBOL(range_ni_E_ai_limited14);
diff --git a/ksrc/drivers/analogy/national_instruments/pcimio.c 
b/ksrc/drivers/analogy/national_instruments/pcimio.c
index 54ea7a0..2c03112 100644
--- a/ksrc/drivers/analogy/national_instruments/pcimio.c
+++ b/ksrc/drivers/analogy/national_instruments/pcimio.c
@@ -1586,6 +1586,8 @@ static void __exit pcimio_cleanup(void)
        a4l_unregister_drv(&pcimio_drv);
 }
 
+MODULE_DESCRIPTION("Analogy driver for NI PCI-MIO series cards");
 MODULE_LICENSE("GPL");
+
 module_init(pcimio_init);
 module_exit(pcimio_cleanup);
diff --git a/ksrc/drivers/analogy/national_instruments/tio_common.c 
b/ksrc/drivers/analogy/national_instruments/tio_common.c
index e7d3939..6944201 100644
--- a/ksrc/drivers/analogy/national_instruments/tio_common.c
+++ b/ksrc/drivers/analogy/national_instruments/tio_common.c
@@ -1960,7 +1960,7 @@ static void __exit ni_tio_cleanup_module(void)
 {
 }
 
-MODULE_DESCRIPTION("Comedi support for NI general-purpose counters");
+MODULE_DESCRIPTION("Analogy support for NI general-purpose counters");
 MODULE_LICENSE("GPL");
 
 module_init(ni_tio_init_module);


_______________________________________________
Xenomai-git mailing list
Xenomai-git@gna.org
https://mail.gna.org/listinfo/xenomai-git

Reply via email to
diff --git a/ksrc/drivers/analogy/intel/8255.c 
b/ksrc/drivers/analogy/intel/8255.c
index 4f9a7ab..ebaa4bb 100644
--- a/ksrc/drivers/analogy/intel/8255.c
+++ b/ksrc/drivers/analogy/intel/8255.c
@@ -1,6 +1,6 @@
 /**
  * @file
  * Analogy for Linux for 8255 chip
  * @note Copyright (C) 1999 David A. Schleef <d...@schleef.org>
  *
  * This library is free software; you can redistribute it and/or
@@ -258,8 +258,8 @@ int dev_8255_attach(a4l_dev_t *dev, a4l_lnkdesc_t *arg)
                                "dev_8255_attach: "
                                "unable to allocate subdevice\n");
                        /* There is no need to free previously
-                          allocated structure(s), the comedi layer will do
-                          it for us */
+                          allocated structure(s), the analogy layer will
+                          do it for us */
                        err = -ENOMEM;
                        goto out_attach;
                }               
@@ -269,7 +269,7 @@ int dev_8255_attach(a4l_dev_t *dev, a4l_lnkdesc_t *arg)
 
                subd_8255 = (subd_8255_t *)subd->priv;          
                
-               if(request_region(addrs[i], _8255_SIZE, "Comedi 8255") == 0) {  
       
+               if(request_region(addrs[i], _8255_SIZE, "Analogy 8255") == 0) { 
       
                        subd->flags = A4L_SUBD_UNUSED;
                        a4l_warn(dev, 
                                 "dev_8255_attach: "
@@ -324,6 +324,8 @@ static void __exit drv_8255_cleanup(void)
 {
        a4l_unregister_drv(&drv_8255);
 }
+MODULE_DESCRIPTION("Analogy driver for 8255 chip");
+MODULE_LICENSE("GPL");
 
 module_init(drv_8255_init);
 module_exit(drv_8255_cleanup);
@@ -1,6 +1,6 @@
 /**
  * @file
- * Analogy for Linux for 8255 chip
+ * Analogy subdevice driver for 8255 chip
  * @note Copyright (C) 1999 David A. Schleef <d...@schleef.org>
  *